@@ -7,7 +7,7 @@ class CorpusHeader:
     Holds the name, intended datatype, and whether to include the header.
     Also behaves as a Value Object, where the unique value is the name for equality checks and hashing.
     """
-    def __init__(self, name: str, datatype: DataType, include: bool = False):
+    def __init__(self, name: str, datatype: DataType, include: bool = True):
         self.name: str = name
         self.datatype: DataType = datatype
         self.include: bool = include
