@@ -1,3 +1,4 @@
+import logging
 import traceback
 from typing import Callable, Optional
 
@@ -5,12 +6,16 @@ from atap_corpus_loader.controller.events import EventType
 
 
 class EventManager:
-    def __init__(self, logger):
-        self.logger = logger
+    def __init__(self, logger_name: str):
+        self.logger_name = logger_name
 
         self.callback_mapping: dict[EventType, list[Callable]] = {}
         self.reset_callbacks()
 
+    def log(self, msg: str, level: int):
+        logger = logging.getLogger(self.logger_name)
+        logger.log(level, msg)
+
     def reset_callbacks(self):
         self.callback_mapping = {e: [] for e in EventType}
 
@@ -18,7 +23,7 @@ class EventManager:
         if not callable(callback):
             raise TypeError("Provided callback function must be callable")
         self.callback_mapping[event_type].append(callback)
-        self.logger.info(f"New callback registered for event '{event_type.name}'. Callback: {callback}")
+        self.log(f"New callback registered for event '{event_type.name}'. Callback: {callback}", logging.INFO)
 
     def trigger_callbacks(self, event_type: EventType, *callback_args):
         callback_list: Optional[list[Callable]] = self.callback_mapping.get(event_type)
@@ -27,6 +32,6 @@ class EventManager:
         for callback in callback_list:
             try:
                 callback(*callback_args)
-                self.logger.info(f"Callback executed for event '{event_type.name}'. Callback: {callback}")
+                self.log(f"Callback executed for event '{event_type.name}'. Callback: {callback}", logging.INFO)
             except Exception as e:
-                self.logger.exception(f"Exception while executing callback for event '{event_type.name}': {type(e)}\n{traceback.format_exc()}")
+                self.log(f"Exception while executing callback for event '{event_type.name}': \n{traceback.format_exc()}", logging.ERROR)
